@@ -752,6 +752,9 @@ class Xliff1File(XliffFile):
     @classmethod
     def parsestring(cls, storestring):
         """Parses the string to return the correct file object."""
+        # pylint: disable-next=import-outside-toplevel
+        from translate.storage import poxliff  # noqa: PLC0415
+
         xliff = super().parsestring(storestring)
         if xliff.units:
             header = xliff.units[0]
@@ -759,8 +762,6 @@ class Xliff1File(XliffFile):
                 "gettext-domain-header" in (header.getrestype() or "")
                 or xliff.getdatatype() == "po"
             ) and cls.__name__.lower() != "poxlifffile":
-                from translate.storage import poxliff
-
                 xliff = poxliff.PoXliffFile.parsestring(storestring)
         return xliff
 
